"""A set of functions to retrieve and save data into MongoDB.
"""

# import package modules
from i_mongodb.i_mongodb import MongoDBInterface, MongoDBDatabase


__version__ = '2.0.0'
